@@ -12,6 +12,15 @@ from os.path import splitext
 import agate
 import six
 
+if six.PY3:
+    import lzma
+elif six.PY2:
+    # Try import backports.lzma if available
+    try:
+        from backports import lzma
+    except ImportError:
+        lzma = None
+
 from csvkit.exceptions import ColumnIdentifierError, RequiredHeaderError
 
 
@@ -225,7 +234,7 @@ class CSVKitUtility(object):
                      '1-based numbering.')
 
         self.argparser.add_argument(
-            '-V', '--version', action='version', version='%(prog)s 1.0.6',
+            '-V', '--version', action='version', version='%(prog)s 1.0.7',
             help='Display version information and exit.')
 
     def _open_input_file(self, path):
@@ -251,6 +260,11 @@ class CSVKitUtility(object):
                     f = LazyFile(bz2.BZ2File, path, mode, **kwargs)
                 else:
                     f = LazyFile(bz2.open, path, mode, **kwargs)
+            elif extension == ".xz":
+                if lzma is not None:
+                    f = LazyFile(lzma.open, path, mode, **kwargs)
+                else:
+                    raise RuntimeError("backports.lzma is needed for .xz support with Python 2")
             else:
                 f = LazyFile(open, path, mode, **kwargs)
 
@@ -376,7 +390,7 @@ class CSVKitUtility(object):
             column_names = next_row
 
         column_offset = self.get_column_offset()
-        if self.args.line_numbers:
+        if kwargs.get('line_numbers'):
             column_offset -= 1
 
         column_ids = parse_column_identifiers(
@@ -407,7 +421,14 @@ class CSVKitUtility(object):
             self.output_file.write('%3i: %s\n' % (i, c))
 
     def additional_input_expected(self):
-        return sys.stdin.isatty() and not self.args.input_path
+        return isatty(sys.stdin) and not self.args.input_path
+
+
+def isatty(f):
+    try:
+        return f.isatty()
+    except ValueError:  # I/O operation on closed file
+        return False
 
 
 def make_default_headers(n):
