@@ -5,10 +5,11 @@ import sys
 
 import agate
 import agatesql  # noqa: F401
+import six
 from pkg_resources import iter_entry_points
 from sqlalchemy import create_engine, dialects
 
-from csvkit.cli import CSVKitUtility
+from csvkit.cli import CSVKitUtility, isatty
 
 DIALECTS = dialects.__all__ + tuple(e.name for e in iter_entry_points('sqlalchemy.dialects'))
 
@@ -68,8 +69,9 @@ class CSVSQL(CSVKitUtility):
             '--db-schema', dest='db_schema',
             help='Optional name of database schema to create table(s) in.')
         self.argparser.add_argument(
-            '-y', '--snifflimit', dest='sniff_limit', type=int,
-            help='Limit CSV dialect sniffing to the specified number of bytes. Specify "0" to disable sniffing.')
+            '-y', '--snifflimit', dest='sniff_limit', type=int, default=1024,
+            help='Limit CSV dialect sniffing to the specified number of bytes. '
+                 'Specify "0" to disable sniffing entirely, or "-1" to sniff the entire file.')
         self.argparser.add_argument(
             '-I', '--no-inference', dest='no_inference', action='store_true',
             help='Disable type inference when parsing the input.')
@@ -78,7 +80,7 @@ class CSVSQL(CSVKitUtility):
             help='Chunk size for batch insert into the table. Requires --insert.')
 
     def main(self):
-        if sys.stdin.isatty() and not self.args.input_paths:
+        if isatty(sys.stdin) and not self.args.input_paths:
             self.argparser.error('You must provide an input file or piped data.')
 
         self.input_files = []
@@ -128,13 +130,13 @@ class CSVSQL(CSVKitUtility):
             try:
                 engine = create_engine(self.args.connection_string)
             except ImportError as e:
-                raise ImportError(
+                six.raise_from(ImportError(
                     "You don't appear to have the necessary database backend installed for connection string you're "
                     "trying to use. Available backends include:\n\nPostgreSQL:\tpip install psycopg2\nMySQL:\t\tpip "
                     "install mysql-connector-python OR pip install mysqlclient\n\nFor details on connection strings "
                     "and other backends, please see the SQLAlchemy documentation on dialects at:\n\n"
                     "http://www.sqlalchemy.org/docs/dialects/\n\n"
-                ) from e
+                ), e)
 
             self.connection = engine.connect()
 
@@ -167,12 +169,13 @@ class CSVSQL(CSVKitUtility):
                     table_name = os.path.splitext(os.path.basename(f.name))[0]
 
             table = None
+            sniff_limit = self.args.sniff_limit if self.args.sniff_limit != -1 else None
 
             try:
                 table = agate.Table.from_csv(
                     f,
                     skip_lines=self.args.skip_lines,
-                    sniff_limit=self.args.sniff_limit,
+                    sniff_limit=sniff_limit,
                     column_types=self.get_column_types(),
                     **self.reader_kwargs
                 )
