@@ -31,6 +31,12 @@ class TestCSVCut(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
             ['1', '3'],
         ])
 
+    def test_linenumbers(self):
+        self.assertRows(['-c', '1,3', '-l', 'examples/dummy.csv'], [
+            ['line_number', 'a', 'c'],
+            ['1', '1', '3'],
+        ])
+
     def test_unicode(self):
         self.assertRows(['-c', '1,3', 'examples/test_utf8.csv'], [
             ['foo', 'baz'],
